import { Octokit } from "@octokit/core";
type Options = {
    owner: string;
    repo: string;
    path: string;
    branch?: string;
};
type Result = {
    content: string | null;
    sha?: string;
};
/**
 * Normalizes the retrival of a repository file content.
 *
 * The "Get repository content" API can respond in 4 different ways depending
 * on what exists at the given path
 *
 * - An array of folder item objects
 * - An object with type = symlink
 * - An object with type = submodule
 * - An object with type = file
 *
 * We are only interested in the last type, and throw errors in all other cases
 *
 * @see https://docs.github.com/en/rest/reference/repos#get-repository-content
 * @param octokit Octokit instance
 * @param options
 */
export declare function getFileContents(octokit: Octokit, options: Options): Promise<Result>;
export {};
